#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the Free Spoken Digit dataset."""

from tensorbay.opendataset.FSDD.loader import FSDD

__all__ = ["FSDD"]
